@@ -1,3 +1,16 @@
+"""Debug Module
+=====================
+This module contains the definition of a functions and decorators to manage logging tools
+used in the framework.
+
+Example:
+    Creating a debug log over a function or method::
+
+        @debug("Debug log")
+        def fun():
+            pass
+"""
+
 import functools
 
 from loguru import logger
@@ -13,11 +26,14 @@ config = {
         }
     ]
 }
+"""Logger configuration."""
 
 logger.configure(**config)
 
 
 def debug(message: str = "", after: bool = False):
+    """Debug decorator."""
+
     def real_decorator(function):
         @functools.wraps(real_decorator)
         def wrapper(*args, **kwargs):
@@ -47,3 +63,20 @@ def debug(message: str = "", after: bool = False):
         return wrapper
 
     return real_decorator
+
+
+def enable_debug():
+    """Enables the debug logs."""
+    logger.remove()
+    new_config = {
+        "handlers": [
+            {
+                "sink": sys.stderr,
+                "level": "DEBUG",
+                "format": "<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | <level>{level: <8}</level> | <level>{"
+                "message}</level>",
+            }
+        ]
+    }
+    logger.remove()
+    logger.configure(**new_config)
