@@ -1,8 +1,24 @@
+"""String Property
+=============================
+Concrete property with str type.
+
+Example:
+    Creating the property::
+
+        property = StringProperty("Hello World")
+"""
+
+
 from gsf.core.entity.core.entity_property import EntityProperty
 from gsf.core.entity.core.property_type import PropertyType
 
 
 class StringProperty(str, EntityProperty):
+    """String Property
+
+    Defines a property with type str
+    """
+
     def __new__(cls, value: str):
         return str.__new__(cls, value)
 
