@@ -1,3 +1,8 @@
+"""Distributions module
+=============================
+Contains the definition of distributions.
+"""
+
 from .random_distribution import RandomDistribution
 from .exponential_distribution import ExponentialDistribution
 from .poisson_distribution import PoissonDistribution
