@@ -1,3 +1,22 @@
+"""Default Report
+=============================
+This module contains the definition of a simulation report.
+It has the definition of the DefaultReport that generates simulation reports in a table format using PrettyTable
+
+Example:
+    Creating a default report::
+
+        report = DefaultReport()
+
+    Saving an output::
+
+        report.add_output({model: model_output}, 1)
+
+    Generating report::
+
+        report.generate_report()
+"""
+
 from typing import Set, Dict
 
 from gsf.core.debug.infrastructure.providers import TableProvider
@@ -5,14 +24,19 @@ from gsf.reports.core.base_report import (
     BaseReport,
     Time,
     DynamicSystemOutput,
-    ReportResult,
 )
 
 
 class DefaultReport(BaseReport):
+    """Default Report
+
+    Creates a report table from the given outputs.
+    """
+
     def _get_results(
         self, headers: Set[str], outputs: Dict[Time, DynamicSystemOutput]
-    ) -> ReportResult:
+    ) -> str:
+        """Creates an str by applying a table format"""
         x = TableProvider()
         x.set_labels(["time"] + list(headers)).set_title("Simulation report")
         for time in outputs:
